@@ -14,5 +14,5 @@ my $response =
 my $format = 'http://static.flickr.com/${server}/${id}_${secret}_m.jpg';
 for my $photo ($response->parse_response->select_nodes('/rsp/photos/photo')) {
     my $image = $format;
-    print $image =~ s/\${(\w+)}/$photo->{attributes}->{$1}/ge && "$image\n";
+    print $image =~ s/\$\{([^{}]+)\}/$photo->{attributes}->{$1}/ge && "$image\n";
 }
